==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/ReportingService/CampaignPerformanceReportColumn.pm <==
package Microsoft::AdCenter::V6::ReportingService::CampaignPerformanceReportColumn;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdDistribution {
    return 'AdDistribution';
}

sub AverageCpc {
    return 'AverageCpc';
}

sub AverageCpm {
    return 'AverageCpm';
}

sub AveragePosition {
    return 'AveragePosition';
}

sub CampaignId {
    return 'CampaignId';
}

sub CampaignName {
    return 'CampaignName';
}

sub Clicks {
    return 'Clicks';
}

sub ConversionRate {
    return 'ConversionRate';
}

sub Conversions {
    return 'Conversions';
}

sub CostPerConversion {
    return 'CostPerConversion';
}

sub Ctr {
    return 'Ctr';
}

sub CurrencyCode {
    return 'CurrencyCode';
}

sub DeviceType {
    return 'DeviceType';
}

sub Impressions {
    return 'Impressions';
}

sub LowQualityClicks {
    return 'LowQualityClicks';
}

sub LowQualityClicksPercent {
    return 'LowQualityClicksPercent';
}

sub LowQualityConversionRate {
    return 'LowQualityConversionRate';
}

sub LowQualityConversions {
    return 'LowQualityConversions';
}

sub LowQualityImpressions {
    return 'LowQualityImpressions';
}

sub LowQualityImpressionsPercent {
    return 'LowQualityImpressionsPercent';
}

sub Spend {
    return 'Spend';
}

sub Status {
    return 'Status';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/ReportingService/CampaignPerformanceReportColumn.pm <==
package Microsoft::AdCenter::V6::ReportingService::CampaignPerformanceReportColumn;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V6::ReportingService::CampaignPerformanceReportColumn - Represents "CampaignPerformanceReportColumn" in Microsoft AdCenter Reporting Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AccountName
AccountNumber
AdDistribution
AverageCpc
AverageCpm
AveragePosition
CampaignId
CampaignName
Clicks
ConversionRate
Conversions
CostPerConversion
Ctr
CurrencyCode
DeviceType
Impressions
LowQualityClicks
LowQualityClicksPercent
LowQualityConversionRate
LowQualityConversions
LowQualityImpressions
LowQualityImpressionsPercent
Spend
Status
TimePeriod

=cut

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdDistribution {
    return 'AdDistribution';
}

sub AverageCpc {
    return 'AverageCpc';
}

sub AverageCpm {
    return 'AverageCpm';
}

sub AveragePosition {
    return 'AveragePosition';
}

sub CampaignId {
    return 'CampaignId';
}

sub CampaignName {
    return 'CampaignName';
}

sub Clicks {
    return 'Clicks';
}

sub ConversionRate {
    return 'ConversionRate';
}

sub Conversions {
    return 'Conversions';
}

sub CostPerConversion {
    return 'CostPerConversion';
}

sub Ctr {
    return 'Ctr';
}

sub CurrencyCode {
    return 'CurrencyCode';
}

sub DeviceType {
    return 'DeviceType';
}

sub Impressions {
    return 'Impressions';
}

sub LowQualityClicks {
    return 'LowQualityClicks';
}

sub LowQualityClicksPercent {
    return 'LowQualityClicksPercent';
}

sub LowQualityConversionRate {
    return 'LowQualityConversionRate';
}

sub LowQualityConversions {
    return 'LowQualityConversions';
}

sub LowQualityImpressions {
    return 'LowQualityImpressions';
}

sub LowQualityImpressionsPercent {
    return 'LowQualityImpressionsPercent';
}

sub Spend {
    return 'Spend';
}

sub Status {
    return 'Status';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;
